==============
robot-tesults
==============

Tesults listener for Robot Framework

------------


Description
------------

Tesults is the new standard in automated test results consolidation, reporting, analysis, failure tracking, manual test reporting and test case management.

Use robot-tesults to automatically integrate Tesults with Robot Framework.

For complete details visit:

https://www.tesults.com/docs?doc=robot


Requirements
------------

The Tesults Python library is required. Install using pip from PyPI:

$ pip install tesults


Installation
------------

Install robot-tesults using pip from PyPI:

$ pip install robot-tesults


Usage
-----

Visit https://www.tesults.com/docs?doc=robot for documentation.


License
-------

Distributed under the terms of the `MIT`_ license, "robot-tesults" is free and open source software


Issues
------

If you encounter any problems, please contact help@tesults.com or visit https://www.tesults.com/contact
